All of lore.kernel.org
 help / color / mirror / Atom feed
* [igt-dev] [PATCH i-g-t 0/2] Test configurable poll delay in perf OA
@ 2020-03-12 23:05 Umesh Nerlige Ramappa
  2020-03-12 23:05 ` [igt-dev] [PATCH i-g-t 1/2] include/drm-uapi: Update i915_drm.h for perf OA APIs Umesh Nerlige Ramappa
                   ` (5 more replies)
  0 siblings, 6 replies; 8+ messages in thread
From: Umesh Nerlige Ramappa @ 2020-03-12 23:05 UTC (permalink / raw)
  To: igt-dev, Ashutosh Dixit, Lionel G Landwerlin

Add tests that verify the configurable poll delay in perf OA.

Lionel Landwerlin (2):
  include/drm-uapi: Update i915_drm.h for perf OA APIs
  tests/perf: new tests for parameterized OA buffer polling

 include/drm-uapi/i915_drm.h |  13 ++++
 tests/perf.c                | 132 ++++++++++++++++++++++++++----------
 2 files changed, 111 insertions(+), 34 deletions(-)

-- 
2.17.1

_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 8+ messages in thread

* [igt-dev] [PATCH i-g-t 1/2] include/drm-uapi: Update i915_drm.h for perf OA APIs
  2020-03-12 23:05 [igt-dev] [PATCH i-g-t 0/2] Test configurable poll delay in perf OA Umesh Nerlige Ramappa
@ 2020-03-12 23:05 ` Umesh Nerlige Ramappa
  2020-03-12 23:05 ` [igt-dev] [PATCH i-g-t 2/2] tests/perf: new tests for parameterized OA buffer polling Umesh Nerlige Ramappa
                   ` (4 subsequent siblings)
  5 siblings, 0 replies; 8+ messages in thread
From: Umesh Nerlige Ramappa @ 2020-03-12 23:05 UTC (permalink / raw)
  To: igt-dev, Ashutosh Dixit, Lionel G Landwerlin

From: Lionel Landwerlin <lionel.g.landwerlin@intel.com>

Add APIs to configure poll delay in perf OA.

v2: (Umesh)
- Remove interrupt and flush APIs
- Change commit message

Signed-off-by: Lionel Landwerlin <lionel.g.landwerlin@intel.com>
Signed-off-by: Umesh Nerlige Ramappa <umesh.nerlige.ramappa@intel.com>
---
 include/drm-uapi/i915_drm.h | 13 +++++++++++++
 1 file changed, 13 insertions(+)

diff --git a/include/drm-uapi/i915_drm.h b/include/drm-uapi/i915_drm.h
index 3794e768..813175c4 100644
--- a/include/drm-uapi/i915_drm.h
+++ b/include/drm-uapi/i915_drm.h
@@ -1969,6 +1969,19 @@ enum drm_i915_perf_property_id {
 	 */
 	DRM_I915_PERF_PROP_HOLD_PREEMPTION,
 
+	/**
+	 * This optional parameter specifies the timer interval in nanoseconds
+	 * at which the i915 driver will check the OA buffer for available data.
+	 * Minimum allowed value is 100 microseconds. A default value is used by
+	 * the driver if this parameter is not specified. Note that a large
+	 * value may reduce cpu consumption during OA perf captures, but it
+	 * would also potentially result in OA buffer overwrite as the captures
+	 * reach end of the OA buffer.
+	 *
+	 * This property is available in perf revision 4.
+	 */
+	DRM_I915_PERF_PROP_POLL_OA_DELAY,
+
 	DRM_I915_PERF_PROP_MAX /* non-ABI */
 };
 
-- 
2.17.1

_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply related	[flat|nested] 8+ messages in thread

* [igt-dev] [PATCH i-g-t 2/2] tests/perf: new tests for parameterized OA buffer polling
  2020-03-12 23:05 [igt-dev] [PATCH i-g-t 0/2] Test configurable poll delay in perf OA Umesh Nerlige Ramappa
  2020-03-12 23:05 ` [igt-dev] [PATCH i-g-t 1/2] include/drm-uapi: Update i915_drm.h for perf OA APIs Umesh Nerlige Ramappa
@ 2020-03-12 23:05 ` Umesh Nerlige Ramappa
  2020-03-13 11:43   ` Lionel Landwerlin
  2020-03-12 23:30 ` [igt-dev] ✗ GitLab.Pipeline: failure for Test configurable poll delay in perf OA Patchwork
                   ` (3 subsequent siblings)
  5 siblings, 1 reply; 8+ messages in thread
From: Umesh Nerlige Ramappa @ 2020-03-12 23:05 UTC (permalink / raw)
  To: igt-dev, Ashutosh Dixit, Lionel G Landwerlin

From: Lionel Landwerlin <lionel.g.landwerlin@intel.com>

2 new tests verifying that the OA buffer is properly checked at the
frequency specified by userspace.

v2: (Umesh)
- Capture start_times in test_polling
- Second parameterized test used a 500us hrtimer. Occassionally, this
  timing does not fall within the duration/100 requirement for the time
  spent in kernel. Change this value to 2ms to accommodate all
  platforms.

Signed-off-by: Lionel Landwerlin <lionel.g.landwerlin@intel.com>
Signed-off-by: Umesh Nerlige Ramappa <umesh.nerlige.ramappa@intel.com>
---
 tests/perf.c | 132 ++++++++++++++++++++++++++++++++++++++-------------
 1 file changed, 98 insertions(+), 34 deletions(-)

diff --git a/tests/perf.c b/tests/perf.c
index 5e818030..f1831550 100644
--- a/tests/perf.c
+++ b/tests/perf.c
@@ -234,6 +234,24 @@ get_oa_format(enum drm_i915_oa_format format)
 		return gen8_oa_formats[format];
 }
 
+static char *
+pretty_print_oa_period(uint64_t oa_period_ns)
+{
+	static char result[100];
+	static const char *units[4] = { "ns", "us", "ms", "s" };
+	double val = oa_period_ns;
+	int iter = 0;
+
+	while (iter < (ARRAY_SIZE(units) - 1) &&
+	       val >= 1000.0f) {
+		val /= 1000.0f;
+		iter++;
+	}
+
+	snprintf(result, sizeof(result), "%.3f%s", val, units[iter]);
+	return result;
+}
+
 static void
 __perf_close(int fd)
 {
@@ -1921,15 +1939,9 @@ get_time(void)
  * kernelspace.
  */
 static void
-test_blocking(void)
+test_blocking(uint64_t requested_oa_period, bool set_kernel_hrtimer, uint64_t kernel_hrtimer)
 {
-	/* ~40 milliseconds
-	 *
-	 * Having a period somewhat > sysconf(_SC_CLK_TCK) helps to stop
-	 * scheduling (liable to kick in when we make blocking poll()s/reads)
-	 * from interfering with the test.
-	 */
-	int oa_exponent = max_oa_exponent_for_period_lte(40000000);
+	int oa_exponent = max_oa_exponent_for_period_lte(requested_oa_period);
 	uint64_t oa_period = oa_exponent_to_ns(oa_exponent);
 	uint64_t properties[] = {
 		/* Include OA reports in samples */
@@ -1939,11 +1951,16 @@ test_blocking(void)
 		DRM_I915_PERF_PROP_OA_METRICS_SET, test_set->perf_oa_metrics_set,
 		DRM_I915_PERF_PROP_OA_FORMAT, test_set->perf_oa_format,
 		DRM_I915_PERF_PROP_OA_EXPONENT, oa_exponent,
+
+		/* Kernel configuration (optional) */
+		DRM_I915_PERF_PROP_POLL_OA_DELAY, kernel_hrtimer,
 	};
 	struct drm_i915_perf_open_param param = {
 		.flags = I915_PERF_FLAG_FD_CLOEXEC |
 			I915_PERF_FLAG_DISABLED,
-		.num_properties = sizeof(properties) / 16,
+		.num_properties = (set_kernel_hrtimer ?
+				   (ARRAY_SIZE(properties) / 2) :
+				   ((ARRAY_SIZE(properties) / 2) - 1)),
 		.properties_ptr = to_user_pointer(properties),
 	};
 	uint8_t buf[1024 * 1024];
@@ -1965,7 +1982,7 @@ test_blocking(void)
 	 * the knowledge that that the driver uses a 200Hz hrtimer (5ms period)
 	 * to check for data and giving some time to read().
 	 */
-	int min_iterations = (test_duration_ns / (oa_period + 6000000ull));
+	int min_iterations = (test_duration_ns / (oa_period + kernel_hrtimer + kernel_hrtimer / 5));
 
 	int64_t start, end;
 	int n = 0;
@@ -1975,9 +1992,10 @@ test_blocking(void)
 	times(&start_times);
 
 	igt_debug("tick length = %dns, test duration = %"PRIu64"ns, min iter. = %d,"
-		  " estimated max iter. = %d, oa_period = %"PRIu64"ns\n",
+		  " estimated max iter. = %d, oa_period = %s\n",
 		  (int)tick_ns, test_duration_ns,
-		  min_iterations, max_iterations, oa_period);
+		  min_iterations, max_iterations,
+		  pretty_print_oa_period(oa_period));
 
 	/* In the loop we perform blocking polls while the HW is sampling at
 	 * ~25Hz, with the expectation that we spend most of our time blocked
@@ -2079,15 +2097,9 @@ test_blocking(void)
 }
 
 static void
-test_polling(void)
+test_polling(uint64_t requested_oa_period, bool set_kernel_hrtimer, uint64_t kernel_hrtimer)
 {
-	/* ~40 milliseconds
-	 *
-	 * Having a period somewhat > sysconf(_SC_CLK_TCK) helps to stop
-	 * scheduling (liable to kick in when we make blocking poll()s/reads)
-	 * from interfering with the test.
-	 */
-	int oa_exponent = max_oa_exponent_for_period_lte(40000000);
+	int oa_exponent = max_oa_exponent_for_period_lte(requested_oa_period);
 	uint64_t oa_period = oa_exponent_to_ns(oa_exponent);
 	uint64_t properties[] = {
 		/* Include OA reports in samples */
@@ -2097,12 +2109,17 @@ test_polling(void)
 		DRM_I915_PERF_PROP_OA_METRICS_SET, test_set->perf_oa_metrics_set,
 		DRM_I915_PERF_PROP_OA_FORMAT, test_set->perf_oa_format,
 		DRM_I915_PERF_PROP_OA_EXPONENT, oa_exponent,
+
+		/* Kernel configuration (optional) */
+		DRM_I915_PERF_PROP_POLL_OA_DELAY, kernel_hrtimer,
 	};
 	struct drm_i915_perf_open_param param = {
 		.flags = I915_PERF_FLAG_FD_CLOEXEC |
 			I915_PERF_FLAG_DISABLED |
 			I915_PERF_FLAG_FD_NONBLOCK,
-		.num_properties = sizeof(properties) / 16,
+		.num_properties = (set_kernel_hrtimer ?
+				   (ARRAY_SIZE(properties) / 2) :
+				   ((ARRAY_SIZE(properties) / 2) - 1)),
 		.properties_ptr = to_user_pointer(properties),
 	};
 	uint8_t buf[1024 * 1024];
@@ -2116,15 +2133,16 @@ test_polling(void)
 	int n_extra_iterations = 0;
 
 	/* It's a bit tricky to put a lower limit here, but we expect a
-	 * relatively low latency for seeing reports, while we don't currently
-	 * give any control over this in the api.
+	 * relatively low latency for seeing reports.
 	 *
 	 * We assume a maximum latency of 6 millisecond to deliver a POLLIN and
 	 * read() after a new sample is written (46ms per iteration) considering
 	 * the knowledge that that the driver uses a 200Hz hrtimer (5ms period)
 	 * to check for data and giving some time to read().
 	 */
-	int min_iterations = (test_duration_ns / (oa_period + 6000000ull));
+	int min_iterations = (test_duration_ns / (oa_period + (kernel_hrtimer + kernel_hrtimer / 5)));
 	int64_t start, end;
 	int n = 0;
 
@@ -2132,8 +2150,9 @@ test_polling(void)
 
 	times(&start_times);
 
-	igt_debug("tick length = %dns, test duration = %"PRIu64"ns, min iter. = %d, max iter. = %d\n",
-		  (int)tick_ns, test_duration_ns,
+	igt_debug("tick length = %dns, oa period = %s, "
+		  "test duration = %"PRIu64"ns, min iter. = %d, max iter. = %d\n",
+		  (int)tick_ns, pretty_print_oa_period(oa_period), test_duration_ns,
 		  min_iterations, max_iterations);
 
 	/* In the loop we perform blocking polls while the HW is sampling at
@@ -4502,6 +4521,23 @@ test_sysctl_defaults(void)
 	igt_assert_eq(max_freq, 100000);
 }
 
+static int i915_perf_revision(int fd)
+{
+	drm_i915_getparam_t gp;
+	int value = 1, ret;
+
+	gp.param = I915_PARAM_PERF_REVISION;
+	gp.value = &value;
+	ret = igt_ioctl(drm_fd, DRM_IOCTL_I915_GETPARAM, &gp);
+	if (ret == -1) {
+		/* If the param is missing, consider version 1. */
+		igt_assert_eq(errno, EINVAL);
+		return 1;
+	}
+
+	return value;
+}
+
 igt_main
 {
 	igt_fixture {
@@ -4584,11 +4620,39 @@ igt_main
 	igt_subtest("enable-disable")
 		test_enable_disable();
 
-	igt_subtest("blocking")
-		test_blocking();
+	igt_subtest("blocking") {
+		test_blocking(40 * 1000 * 1000 /* 40ms oa period */,
+			      false /* set_kernel_hrtimer */,
+			      5 * 1000 * 1000 /* default 5ms/200Hz hrtimer */);
+	}
+
+	igt_subtest("blocking-parameterized") {
+		igt_require(i915_perf_revision(drm_fd) >= 2);
+
+		test_blocking(10 * 1000 * 1000 /* 10ms oa period */,
+			      true /* set_kernel_hrtimer */,
+			      40 * 1000 * 1000 /* default 40ms hrtimer */);
+		test_blocking(500 * 1000 /* 500us oa period */,
+			      true /* set_kernel_hrtimer */,
+			      2 * 1000 * 1000 /* default 2ms hrtimer */);
+	}
 
-	igt_subtest("polling")
-		test_polling();
+	igt_subtest("polling") {
+		test_polling(40 * 1000 * 1000 /* 40ms oa period */,
+			     false /* set_kernel_hrtimer */,
+			     5 * 1000 * 1000 /* default 5ms/200Hz hrtimer */);
+	}
+
+	igt_subtest("polling-parameterized") {
+		igt_require(i915_perf_revision(drm_fd) >= 2);
+
+		test_polling(10 * 1000 * 1000 /* 10ms oa period */,
+			     true /* set_kernel_hrtimer */,
+			     40 * 1000 * 1000 /* default 40ms hrtimer */);
+		test_polling(500 * 1000 /* 500us oa period */,
+			     true /* set_kernel_hrtimer */,
+			     2 * 1000 * 1000 /* default 2ms hrtimer */);
+	}
 
 	igt_subtest("short-reads")
 		test_short_reads();
@@ -2116,15 +2133,16 @@ test_polling(void)
 	 *
-	 * We assume a maximum latency of 6 millisecond to deliver a POLLIN and
-	 * read() after a new sample is written (46ms per iteration) considering
-	 * the knowledge that that the driver uses a 200Hz hrtimer (5ms period)
-	 * to check for data and giving some time to read().
+	 * We assume a maximum latency of kernel_hrtimer + some margin
+	 * to deliver a POLLIN and read() after a new sample is
+	 * written (40ms + hrtimer + margin per iteration) considering
+	 * the knowledge that that the driver uses a 200Hz hrtimer
+	 * (5ms period) to check for data and giving some time to
+	 * read().
 	 */
-- 
2.17.1

_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply related	[flat|nested] 8+ messages in thread

* [igt-dev] ✗ GitLab.Pipeline: failure for Test configurable poll delay in perf OA
  2020-03-12 23:05 [igt-dev] [PATCH i-g-t 0/2] Test configurable poll delay in perf OA Umesh Nerlige Ramappa
  2020-03-12 23:05 ` [igt-dev] [PATCH i-g-t 1/2] include/drm-uapi: Update i915_drm.h for perf OA APIs Umesh Nerlige Ramappa
  2020-03-12 23:05 ` [igt-dev] [PATCH i-g-t 2/2] tests/perf: new tests for parameterized OA buffer polling Umesh Nerlige Ramappa
@ 2020-03-12 23:30 ` Patchwork
  2020-03-12 23:40 ` [igt-dev] ✓ Fi.CI.BAT: success " Patchwork
                   ` (2 subsequent siblings)
  5 siblings, 0 replies; 8+ messages in thread
From: Patchwork @ 2020-03-12 23:30 UTC (permalink / raw)
  To: Umesh Nerlige Ramappa; +Cc: igt-dev

== Series Details ==

Series: Test configurable poll delay in perf OA
URL   : https://patchwork.freedesktop.org/series/74655/
State : failure

== Summary ==

ERROR! This series introduces new undocumented tests:

perf@blocking-parameterized
perf@polling-parameterized

Can you document them as per the requirement in the [CONTRIBUTING.md]?

[Documentation] has more details on how to do this.

Here are few examples:
https://gitlab.freedesktop.org/drm/igt-gpu-tools/commit/0316695d03aa46108296b27f3982ec93200c7a6e
https://gitlab.freedesktop.org/drm/igt-gpu-tools/commit/443cc658e1e6b492ee17bf4f4d891029eb7a205d

Thanks in advance!

[CONTRIBUTING.md]: https://gitlab.freedesktop.org/drm/igt-gpu-tools/blob/master/CONTRIBUTING.md#L19
[Documentation]: https://drm.pages.freedesktop.org/igt-gpu-tools/igt-gpu-tools-Core.html#igt-describe

Other than that, pipeline status: SUCCESS.

see https://gitlab.freedesktop.org/gfx-ci/igt-ci-tags/pipelines/119318 for the overview.

== Logs ==

For more details see: https://gitlab.freedesktop.org/gfx-ci/igt-ci-tags/pipelines/119318
_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 8+ messages in thread

* [igt-dev] ✓ Fi.CI.BAT: success for Test configurable poll delay in perf OA
  2020-03-12 23:05 [igt-dev] [PATCH i-g-t 0/2] Test configurable poll delay in perf OA Umesh Nerlige Ramappa
                   ` (2 preceding siblings ...)
  2020-03-12 23:30 ` [igt-dev] ✗ GitLab.Pipeline: failure for Test configurable poll delay in perf OA Patchwork
@ 2020-03-12 23:40 ` Patchwork
  2020-03-13 12:38 ` [igt-dev] ✓ Fi.CI.IGT: " Patchwork
  2020-03-13 13:27 ` [igt-dev] [PATCH i-g-t 0/2] " Lionel Landwerlin
  5 siblings, 0 replies; 8+ messages in thread
From: Patchwork @ 2020-03-12 23:40 UTC (permalink / raw)
  To: Umesh Nerlige Ramappa; +Cc: igt-dev

== Series Details ==

Series: Test configurable poll delay in perf OA
URL   : https://patchwork.freedesktop.org/series/74655/
State : success

== Summary ==

CI Bug Log - changes from CI_DRM_8130 -> IGTPW_4299
====================================================

Summary
-------

  **SUCCESS**

  No regressions found.

  External URL: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/index.html

Known issues
------------

  Here are the changes found in IGTPW_4299 that come from known issues:

### IGT changes ###

#### Issues hit ####

  * igt@gem_exec_suspend@basic-s4-devices:
    - fi-tgl-y:           [PASS][1] -> [FAIL][2] ([CI#94])
   [1]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/fi-tgl-y/igt@gem_exec_suspend@basic-s4-devices.html
   [2]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/fi-tgl-y/igt@gem_exec_suspend@basic-s4-devices.html

  * igt@i915_selftest@live@execlists:
    - fi-apl-guc:         [PASS][3] -> [INCOMPLETE][4] ([fdo#103927])
   [3]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/fi-apl-guc/igt@i915_selftest@live@execlists.html
   [4]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/fi-apl-guc/igt@i915_selftest@live@execlists.html

  * igt@i915_selftest@live@hangcheck:
    - fi-icl-guc:         [PASS][5] -> [INCOMPLETE][6] ([fdo#108569])
   [5]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/fi-icl-guc/igt@i915_selftest@live@hangcheck.html
   [6]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/fi-icl-guc/igt@i915_selftest@live@hangcheck.html
    - fi-apl-guc:         [PASS][7] -> [DMESG-WARN][8] ([i915#1430])
   [7]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/fi-apl-guc/igt@i915_selftest@live@hangcheck.html
   [8]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/fi-apl-guc/igt@i915_selftest@live@hangcheck.html

  
#### Possible fixes ####

  * igt@i915_selftest@live@execlists:
    - fi-icl-y:           [DMESG-FAIL][9] ([fdo#108569]) -> [PASS][10]
   [9]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/fi-icl-y/igt@i915_selftest@live@execlists.html
   [10]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/fi-icl-y/igt@i915_selftest@live@execlists.html

  * igt@kms_chamelium@hdmi-hpd-fast:
    - fi-kbl-7500u:       [FAIL][11] ([i915#323]) -> [PASS][12]
   [11]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/fi-kbl-7500u/igt@kms_chamelium@hdmi-hpd-fast.html
   [12]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/fi-kbl-7500u/igt@kms_chamelium@hdmi-hpd-fast.html

  
  {name}: This element is suppressed. This means it is ignored when computing
          the status of the difference (SUCCESS, WARNING, or FAILURE).

  [CI#94]: https://gitlab.freedesktop.org/gfx-ci/i915-infra/issues/94
  [fdo#103927]: https://bugs.freedesktop.org/show_bug.cgi?id=103927
  [fdo#108569]: https://bugs.freedesktop.org/show_bug.cgi?id=108569
  [fdo#112259]: https://bugs.freedesktop.org/show_bug.cgi?id=112259
  [i915#1430]: https://gitlab.freedesktop.org/drm/intel/issues/1430
  [i915#323]: https://gitlab.freedesktop.org/drm/intel/issues/323
  [i915#656]: https://gitlab.freedesktop.org/drm/intel/issues/656


Participating hosts (41 -> 43)
------------------------------

  Additional (7): fi-bsw-n3050 fi-byt-j1900 fi-glk-dsi fi-kbl-guc fi-cfl-8109u fi-blb-e6850 fi-kbl-r 
  Missing    (5): fi-hsw-4200u fi-skl-6770hq fi-byt-squawks fi-bsw-cyan fi-bdw-samus 


Build changes
-------------

  * CI: CI-20190529 -> None
  * IGT: IGT_5506 -> IGTPW_4299

  CI-20190529: 20190529
  CI_DRM_8130: cf47ad003bc75f001bd33caedb28c8ba2e3c3d33 @ git://anongit.freedesktop.org/gfx-ci/linux
  IGTPW_4299: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/index.html
  IGT_5506: 59fd8a0d01dac58dc6c7d86ef391ed4393ab5aae @ git://anongit.freedesktop.org/xorg/app/intel-gpu-tools



== Testlist changes ==

+igt@perf@blocking-parameterized
+igt@perf@polling-parameterized

== Logs ==

For more details see: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/index.html
_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 8+ messages in thread

* Re: [igt-dev] [PATCH i-g-t 2/2] tests/perf: new tests for parameterized OA buffer polling
  2020-03-12 23:05 ` [igt-dev] [PATCH i-g-t 2/2] tests/perf: new tests for parameterized OA buffer polling Umesh Nerlige Ramappa
@ 2020-03-13 11:43   ` Lionel Landwerlin
  0 siblings, 0 replies; 8+ messages in thread
From: Lionel Landwerlin @ 2020-03-13 11:43 UTC (permalink / raw)
  To: Umesh Nerlige Ramappa, igt-dev, Ashutosh Dixit

On 13/03/2020 01:05, Umesh Nerlige Ramappa wrote:
> From: Lionel Landwerlin <lionel.g.landwerlin@intel.com>
>
> 2 new tests verifying that the OA buffer is properly checked at the
> frequency specified by userspace.
>
> v2: (Umesh)
> - Capture start_times in test_polling
> - Second parameterized test used a 500us hrtimer. Occassionally, this
>    timing does not fall within the duration/100 requirement for the time
>    spent in kernel. Change this value to 2ms to accommodate all
>    platforms.
>
> Signed-off-by: Lionel Landwerlin <lionel.g.landwerlin@intel.com>
> Signed-off-by: Umesh Nerlige Ramappa <umesh.nerlige.ramappa@intel.com>
> ---
>   tests/perf.c | 132 ++++++++++++++++++++++++++++++++++++++-------------
>   1 file changed, 98 insertions(+), 34 deletions(-)
>
> diff --git a/tests/perf.c b/tests/perf.c
> index 5e818030..f1831550 100644
> --- a/tests/perf.c
> +++ b/tests/perf.c
> @@ -234,6 +234,24 @@ get_oa_format(enum drm_i915_oa_format format)
>   		return gen8_oa_formats[format];
>   }
>   
> +static char *
> +pretty_print_oa_period(uint64_t oa_period_ns)
> +{
> +	static char result[100];
> +	static const char *units[4] = { "ns", "us", "ms", "s" };
> +	double val = oa_period_ns;
> +	int iter = 0;
> +
> +	while (iter < (ARRAY_SIZE(units) - 1) &&
> +	       val >= 1000.0f) {
> +		val /= 1000.0f;
> +		iter++;
> +	}
> +
> +	snprintf(result, sizeof(result), "%.3f%s", val, units[iter]);
> +	return result;
> +}
> +
>   static void
>   __perf_close(int fd)
>   {
> @@ -1921,15 +1939,9 @@ get_time(void)
>    * kernelspace.
>    */
>   static void
> -test_blocking(void)
> +test_blocking(uint64_t requested_oa_period, bool set_kernel_hrtimer, uint64_t kernel_hrtimer)
>   {
> -	/* ~40 milliseconds
> -	 *
> -	 * Having a period somewhat > sysconf(_SC_CLK_TCK) helps to stop
> -	 * scheduling (liable to kick in when we make blocking poll()s/reads)
> -	 * from interfering with the test.
> -	 */
> -	int oa_exponent = max_oa_exponent_for_period_lte(40000000);
> +	int oa_exponent = max_oa_exponent_for_period_lte(requested_oa_period);
>   	uint64_t oa_period = oa_exponent_to_ns(oa_exponent);
>   	uint64_t properties[] = {
>   		/* Include OA reports in samples */
> @@ -1939,11 +1951,16 @@ test_blocking(void)
>   		DRM_I915_PERF_PROP_OA_METRICS_SET, test_set->perf_oa_metrics_set,
>   		DRM_I915_PERF_PROP_OA_FORMAT, test_set->perf_oa_format,
>   		DRM_I915_PERF_PROP_OA_EXPONENT, oa_exponent,
> +
> +		/* Kernel configuration (optional) */
> +		DRM_I915_PERF_PROP_POLL_OA_DELAY, kernel_hrtimer,
>   	};
>   	struct drm_i915_perf_open_param param = {
>   		.flags = I915_PERF_FLAG_FD_CLOEXEC |
>   			I915_PERF_FLAG_DISABLED,
> -		.num_properties = sizeof(properties) / 16,
> +		.num_properties = (set_kernel_hrtimer ?
> +				   (ARRAY_SIZE(properties) / 2) :
> +				   ((ARRAY_SIZE(properties) / 2) - 1)),


There is a NUM_PROPERTIES() macro at the top of the file you could reuse 
for this :


set_kernel_hrtimer ? NUM_PROPERTIES(properties) : 
(NUM_PROPERTIES(properties) - 1)


>   		.properties_ptr = to_user_pointer(properties),
>   	};
>   	uint8_t buf[1024 * 1024];
> @@ -1965,7 +1982,7 @@ test_blocking(void)
>   	 * the knowledge that that the driver uses a 200Hz hrtimer (5ms period)
>   	 * to check for data and giving some time to read().
>   	 */
> -	int min_iterations = (test_duration_ns / (oa_period + 6000000ull));
> +	int min_iterations = (test_duration_ns / (oa_period + kernel_hrtimer + kernel_hrtimer / 5));
>   
>   	int64_t start, end;
>   	int n = 0;
> @@ -1975,9 +1992,10 @@ test_blocking(void)
>   	times(&start_times);
>   
>   	igt_debug("tick length = %dns, test duration = %"PRIu64"ns, min iter. = %d,"
> -		  " estimated max iter. = %d, oa_period = %"PRIu64"ns\n",
> +		  " estimated max iter. = %d, oa_period = %s\n",
>   		  (int)tick_ns, test_duration_ns,
> -		  min_iterations, max_iterations, oa_period);
> +		  min_iterations, max_iterations,
> +		  pretty_print_oa_period(oa_period));
>   
>   	/* In the loop we perform blocking polls while the HW is sampling at
>   	 * ~25Hz, with the expectation that we spend most of our time blocked
> @@ -2079,15 +2097,9 @@ test_blocking(void)
>   }
>   
>   static void
> -test_polling(void)
> +test_polling(uint64_t requested_oa_period, bool set_kernel_hrtimer, uint64_t kernel_hrtimer)
>   {
> -	/* ~40 milliseconds
> -	 *
> -	 * Having a period somewhat > sysconf(_SC_CLK_TCK) helps to stop
> -	 * scheduling (liable to kick in when we make blocking poll()s/reads)
> -	 * from interfering with the test.
> -	 */
> -	int oa_exponent = max_oa_exponent_for_period_lte(40000000);
> +	int oa_exponent = max_oa_exponent_for_period_lte(requested_oa_period);
>   	uint64_t oa_period = oa_exponent_to_ns(oa_exponent);
>   	uint64_t properties[] = {
>   		/* Include OA reports in samples */
> @@ -2097,12 +2109,17 @@ test_polling(void)
>   		DRM_I915_PERF_PROP_OA_METRICS_SET, test_set->perf_oa_metrics_set,
>   		DRM_I915_PERF_PROP_OA_FORMAT, test_set->perf_oa_format,
>   		DRM_I915_PERF_PROP_OA_EXPONENT, oa_exponent,
> +
> +		/* Kernel configuration (optional) */
> +		DRM_I915_PERF_PROP_POLL_OA_DELAY, kernel_hrtimer,
>   	};
>   	struct drm_i915_perf_open_param param = {
>   		.flags = I915_PERF_FLAG_FD_CLOEXEC |
>   			I915_PERF_FLAG_DISABLED |
>   			I915_PERF_FLAG_FD_NONBLOCK,
> -		.num_properties = sizeof(properties) / 16,
> +		.num_properties = (set_kernel_hrtimer ?
> +				   (ARRAY_SIZE(properties) / 2) :
> +				   ((ARRAY_SIZE(properties) / 2) - 1)),


Same here.


>   		.properties_ptr = to_user_pointer(properties),
>   	};
>   	uint8_t buf[1024 * 1024];
> @@ -2116,15 +2133,16 @@ test_polling(void)
>   	int n_extra_iterations = 0;
>   
>   	/* It's a bit tricky to put a lower limit here, but we expect a
> -	 * relatively low latency for seeing reports, while we don't currently
> -	 * give any control over this in the api.
> +	 * relatively low latency for seeing reports.
>   	 *
> -	 * We assume a maximum latency of 6 millisecond to deliver a POLLIN and
> -	 * read() after a new sample is written (46ms per iteration) considering
> -	 * the knowledge that that the driver uses a 200Hz hrtimer (5ms period)
> -	 * to check for data and giving some time to read().
> +	 * We assume a maximum latency of kernel_hrtimer + some margin
> +	 * to deliver a POLLIN and read() after a new sample is
> +	 * written (40ms + hrtimer + margin per iteration) considering
> +	 * the knowledge that that the driver uses a 200Hz hrtimer
> +	 * (5ms period) to check for data and giving some time to
> +	 * read().
>   	 */
> -	int min_iterations = (test_duration_ns / (oa_period + 6000000ull));
> +	int min_iterations = (test_duration_ns / (oa_period + (kernel_hrtimer + kernel_hrtimer / 5)));
>   	int64_t start, end;
>   	int n = 0;
>   
> @@ -2132,8 +2150,9 @@ test_polling(void)
>   
>   	times(&start_times);
>   
> -	igt_debug("tick length = %dns, test duration = %"PRIu64"ns, min iter. = %d, max iter. = %d\n",
> -		  (int)tick_ns, test_duration_ns,
> +	igt_debug("tick length = %dns, oa period = %s, "
> +		  "test duration = %"PRIu64"ns, min iter. = %d, max iter. = %d\n",
> +		  (int)tick_ns, pretty_print_oa_period(oa_period), test_duration_ns,
>   		  min_iterations, max_iterations);
>   
>   	/* In the loop we perform blocking polls while the HW is sampling at
> @@ -4502,6 +4521,23 @@ test_sysctl_defaults(void)
>   	igt_assert_eq(max_freq, 100000);
>   }
>   
> +static int i915_perf_revision(int fd)
> +{
> +	drm_i915_getparam_t gp;
> +	int value = 1, ret;
> +
> +	gp.param = I915_PARAM_PERF_REVISION;
> +	gp.value = &value;
> +	ret = igt_ioctl(drm_fd, DRM_IOCTL_I915_GETPARAM, &gp);
> +	if (ret == -1) {
> +		/* If the param is missing, consider version 1. */
> +		igt_assert_eq(errno, EINVAL);
> +		return 1;
> +	}
> +
> +	return value;
> +}
> +
>   igt_main
>   {
>   	igt_fixture {
> @@ -4584,11 +4620,39 @@ igt_main
>   	igt_subtest("enable-disable")
>   		test_enable_disable();
>   
> -	igt_subtest("blocking")
> -		test_blocking();
> +	igt_subtest("blocking") {
> +		test_blocking(40 * 1000 * 1000 /* 40ms oa period */,
> +			      false /* set_kernel_hrtimer */,
> +			      5 * 1000 * 1000 /* default 5ms/200Hz hrtimer */);
> +	}
> +
> +	igt_subtest("blocking-parameterized") {
> +		igt_require(i915_perf_revision(drm_fd) >= 2);
The kernel patches are revision 4.
> +
> +		test_blocking(10 * 1000 * 1000 /* 10ms oa period */,
> +			      true /* set_kernel_hrtimer */,
> +			      40 * 1000 * 1000 /* default 40ms hrtimer */);
> +		test_blocking(500 * 1000 /* 500us oa period */,
> +			      true /* set_kernel_hrtimer */,
> +			      2 * 1000 * 1000 /* default 2ms hrtimer */);
> +	}
>   
> -	igt_subtest("polling")
> -		test_polling();
> +	igt_subtest("polling") {
> +		test_polling(40 * 1000 * 1000 /* 40ms oa period */,
> +			     false /* set_kernel_hrtimer */,
> +			     5 * 1000 * 1000 /* default 5ms/200Hz hrtimer */);
> +	}
> +
> +	igt_subtest("polling-parameterized") {
> +		igt_require(i915_perf_revision(drm_fd) >= 2);
Same revision 4 here.
> +
> +		test_polling(10 * 1000 * 1000 /* 10ms oa period */,
> +			     true /* set_kernel_hrtimer */,
> +			     40 * 1000 * 1000 /* default 40ms hrtimer */);
> +		test_polling(500 * 1000 /* 500us oa period */,
> +			     true /* set_kernel_hrtimer */,
> +			     2 * 1000 * 1000 /* default 2ms hrtimer */);
> +	}
>   
>   	igt_subtest("short-reads")
>   		test_short_reads();


_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 8+ messages in thread

* [igt-dev] ✓ Fi.CI.IGT: success for Test configurable poll delay in perf OA
  2020-03-12 23:05 [igt-dev] [PATCH i-g-t 0/2] Test configurable poll delay in perf OA Umesh Nerlige Ramappa
                   ` (3 preceding siblings ...)
  2020-03-12 23:40 ` [igt-dev] ✓ Fi.CI.BAT: success " Patchwork
@ 2020-03-13 12:38 ` Patchwork
  2020-03-13 13:27 ` [igt-dev] [PATCH i-g-t 0/2] " Lionel Landwerlin
  5 siblings, 0 replies; 8+ messages in thread
From: Patchwork @ 2020-03-13 12:38 UTC (permalink / raw)
  To: Umesh Nerlige Ramappa; +Cc: igt-dev

== Series Details ==

Series: Test configurable poll delay in perf OA
URL   : https://patchwork.freedesktop.org/series/74655/
State : success

== Summary ==

CI Bug Log - changes from CI_DRM_8130_full -> IGTPW_4299_full
====================================================

Summary
-------

  **SUCCESS**

  No regressions found.

  External URL: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/index.html

Possible new issues
-------------------

  Here are the unknown changes that may have been introduced in IGTPW_4299_full:

### IGT changes ###

#### Possible regressions ####

  * {igt@perf@blocking-parameterized} (NEW):
    - shard-kbl:          NOTRUN -> [FAIL][1] +1 similar issue
   [1]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-kbl3/igt@perf@blocking-parameterized.html
    - shard-iclb:         NOTRUN -> [FAIL][2] +1 similar issue
   [2]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb6/igt@perf@blocking-parameterized.html
    - shard-apl:          NOTRUN -> [FAIL][3] +1 similar issue
   [3]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-apl8/igt@perf@blocking-parameterized.html

  * {igt@perf@polling-parameterized} (NEW):
    - shard-glk:          NOTRUN -> [FAIL][4] +1 similar issue
   [4]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-glk6/igt@perf@polling-parameterized.html
    - shard-hsw:          NOTRUN -> [FAIL][5]
   [5]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-hsw2/igt@perf@polling-parameterized.html
    - shard-tglb:         NOTRUN -> [FAIL][6] +1 similar issue
   [6]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-tglb5/igt@perf@polling-parameterized.html

  
New tests
---------

  New tests have been introduced between CI_DRM_8130_full and IGTPW_4299_full:

### New IGT tests (2) ###

  * igt@perf@blocking-parameterized:
    - Statuses : 5 fail(s)
    - Exec time: [0.01, 0.02] s

  * igt@perf@polling-parameterized:
    - Statuses : 6 fail(s) 1 skip(s)
    - Exec time: [0.0, 0.34] s

  

Known issues
------------

  Here are the changes found in IGTPW_4299_full that come from known issues:

### IGT changes ###

#### Issues hit ####

  * igt@gem_exec_balancer@smoke:
    - shard-iclb:         [PASS][7] -> [SKIP][8] ([fdo#110854])
   [7]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb1/igt@gem_exec_balancer@smoke.html
   [8]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb6/igt@gem_exec_balancer@smoke.html

  * igt@gem_exec_schedule@pi-distinct-iova-bsd:
    - shard-iclb:         [PASS][9] -> [SKIP][10] ([i915#677]) +2 similar issues
   [9]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb7/igt@gem_exec_schedule@pi-distinct-iova-bsd.html
   [10]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb2/igt@gem_exec_schedule@pi-distinct-iova-bsd.html

  * igt@gem_exec_schedule@promotion-bsd1:
    - shard-iclb:         [PASS][11] -> [SKIP][12] ([fdo#109276]) +21 similar issues
   [11]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb2/igt@gem_exec_schedule@promotion-bsd1.html
   [12]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb8/igt@gem_exec_schedule@promotion-bsd1.html

  * igt@gem_exec_schedule@reorder-wide-bsd:
    - shard-iclb:         [PASS][13] -> [SKIP][14] ([fdo#112146]) +2 similar issues
   [13]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb8/igt@gem_exec_schedule@reorder-wide-bsd.html
   [14]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb2/igt@gem_exec_schedule@reorder-wide-bsd.html

  * igt@gem_ppgtt@flink-and-close-vma-leak:
    - shard-glk:          [PASS][15] -> [FAIL][16] ([i915#644])
   [15]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-glk4/igt@gem_ppgtt@flink-and-close-vma-leak.html
   [16]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-glk5/igt@gem_ppgtt@flink-and-close-vma-leak.html

  * igt@gem_workarounds@suspend-resume-fd:
    - shard-kbl:          [PASS][17] -> [DMESG-WARN][18] ([i915#180]) +2 similar issues
   [17]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-kbl4/igt@gem_workarounds@suspend-resume-fd.html
   [18]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-kbl3/igt@gem_workarounds@suspend-resume-fd.html

  * igt@gen9_exec_parse@allowed-all:
    - shard-glk:          [PASS][19] -> [INCOMPLETE][20] ([i915#58] / [k.org#198133])
   [19]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-glk2/igt@gen9_exec_parse@allowed-all.html
   [20]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-glk4/igt@gen9_exec_parse@allowed-all.html

  * igt@i915_pm_rpm@debugfs-forcewake-user:
    - shard-hsw:          [PASS][21] -> [SKIP][22] ([fdo#109271]) +1 similar issue
   [21]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-hsw5/igt@i915_pm_rpm@debugfs-forcewake-user.html
   [22]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-hsw5/igt@i915_pm_rpm@debugfs-forcewake-user.html
    - shard-iclb:         [PASS][23] -> [SKIP][24] ([i915#1316])
   [23]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb4/igt@i915_pm_rpm@debugfs-forcewake-user.html
   [24]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb3/igt@i915_pm_rpm@debugfs-forcewake-user.html
    - shard-tglb:         [PASS][25] -> [SKIP][26] ([i915#1316])
   [25]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-tglb6/igt@i915_pm_rpm@debugfs-forcewake-user.html
   [26]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-tglb8/igt@i915_pm_rpm@debugfs-forcewake-user.html

  * igt@i915_pm_rpm@modeset-non-lpsp-stress-no-wait:
    - shard-glk:          [PASS][27] -> [SKIP][28] ([fdo#109271]) +1 similar issue
   [27]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-glk9/igt@i915_pm_rpm@modeset-non-lpsp-stress-no-wait.html
   [28]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-glk7/igt@i915_pm_rpm@modeset-non-lpsp-stress-no-wait.html

  * igt@kms_color@pipe-c-ctm-green-to-red:
    - shard-kbl:          [PASS][29] -> [FAIL][30] ([i915#129])
   [29]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-kbl7/igt@kms_color@pipe-c-ctm-green-to-red.html
   [30]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-kbl4/igt@kms_color@pipe-c-ctm-green-to-red.html
    - shard-apl:          [PASS][31] -> [FAIL][32] ([i915#129])
   [31]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-apl4/igt@kms_color@pipe-c-ctm-green-to-red.html
   [32]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-apl2/igt@kms_color@pipe-c-ctm-green-to-red.html

  * igt@kms_cursor_crc@pipe-a-cursor-suspend:
    - shard-kbl:          [PASS][33] -> [INCOMPLETE][34] ([i915#155])
   [33]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-kbl2/igt@kms_cursor_crc@pipe-a-cursor-suspend.html
   [34]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-kbl1/igt@kms_cursor_crc@pipe-a-cursor-suspend.html

  * igt@kms_cursor_crc@pipe-b-cursor-dpms:
    - shard-apl:          [PASS][35] -> [FAIL][36] ([i915#54]) +1 similar issue
   [35]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-apl2/igt@kms_cursor_crc@pipe-b-cursor-dpms.html
   [36]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-apl7/igt@kms_cursor_crc@pipe-b-cursor-dpms.html

  * igt@kms_flip@flip-vs-expired-vblank:
    - shard-apl:          [PASS][37] -> [FAIL][38] ([i915#79])
   [37]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-apl1/igt@kms_flip@flip-vs-expired-vblank.html
   [38]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-apl7/igt@kms_flip@flip-vs-expired-vblank.html

  * igt@kms_flip@flip-vs-expired-vblank-interruptible:
    - shard-glk:          [PASS][39] -> [FAIL][40] ([i915#79]) +1 similar issue
   [39]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-glk5/igt@kms_flip@flip-vs-expired-vblank-interruptible.html
   [40]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-glk7/igt@kms_flip@flip-vs-expired-vblank-interruptible.html

  * igt@kms_flip@plain-flip-ts-check-interruptible:
    - shard-glk:          [PASS][41] -> [FAIL][42] ([i915#34])
   [41]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-glk7/igt@kms_flip@plain-flip-ts-check-interruptible.html
   [42]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-glk4/igt@kms_flip@plain-flip-ts-check-interruptible.html

  * igt@kms_plane@plane-panning-bottom-right-suspend-pipe-a-planes:
    - shard-iclb:         [PASS][43] -> [INCOMPLETE][44] ([i915#250])
   [43]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb6/igt@kms_plane@plane-panning-bottom-right-suspend-pipe-a-planes.html
   [44]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb3/igt@kms_plane@plane-panning-bottom-right-suspend-pipe-a-planes.html

  * igt@kms_plane_cursor@pipe-c-viewport-size-64:
    - shard-apl:          [PASS][45] -> [INCOMPLETE][46] ([fdo#103927])
   [45]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-apl3/igt@kms_plane_cursor@pipe-c-viewport-size-64.html
   [46]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-apl1/igt@kms_plane_cursor@pipe-c-viewport-size-64.html

  * igt@kms_psr2_su@frontbuffer:
    - shard-iclb:         [PASS][47] -> [SKIP][48] ([fdo#109642] / [fdo#111068])
   [47]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb2/igt@kms_psr2_su@frontbuffer.html
   [48]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb8/igt@kms_psr2_su@frontbuffer.html

  * igt@kms_setmode@basic:
    - shard-apl:          [PASS][49] -> [FAIL][50] ([i915#31])
   [49]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-apl6/igt@kms_setmode@basic.html
   [50]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-apl3/igt@kms_setmode@basic.html
    - shard-glk:          [PASS][51] -> [FAIL][52] ([i915#31])
   [51]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-glk4/igt@kms_setmode@basic.html
   [52]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-glk6/igt@kms_setmode@basic.html

  * igt@kms_vblank@pipe-b-ts-continuation-suspend:
    - shard-apl:          [PASS][53] -> [DMESG-WARN][54] ([i915#180]) +3 similar issues
   [53]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-apl1/igt@kms_vblank@pipe-b-ts-continuation-suspend.html
   [54]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-apl1/igt@kms_vblank@pipe-b-ts-continuation-suspend.html

  * igt@perf_pmu@busy-vcs1:
    - shard-iclb:         [PASS][55] -> [SKIP][56] ([fdo#112080]) +14 similar issues
   [55]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb1/igt@perf_pmu@busy-vcs1.html
   [56]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb5/igt@perf_pmu@busy-vcs1.html

  
#### Possible fixes ####

  * igt@gem_busy@busy-vcs1:
    - shard-iclb:         [SKIP][57] ([fdo#112080]) -> [PASS][58] +11 similar issues
   [57]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb3/igt@gem_busy@busy-vcs1.html
   [58]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb2/igt@gem_busy@busy-vcs1.html

  * igt@gem_ctx_persistence@close-replace-race:
    - shard-kbl:          [INCOMPLETE][59] ([i915#1402]) -> [PASS][60]
   [59]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-kbl4/igt@gem_ctx_persistence@close-replace-race.html
   [60]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-kbl3/igt@gem_ctx_persistence@close-replace-race.html

  * igt@gem_ctx_shared@exec-single-timeline-bsd:
    - shard-iclb:         [SKIP][61] ([fdo#110841]) -> [PASS][62]
   [61]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb4/igt@gem_ctx_shared@exec-single-timeline-bsd.html
   [62]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb5/igt@gem_ctx_shared@exec-single-timeline-bsd.html

  * igt@gem_exec_async@concurrent-writes-bsd:
    - shard-iclb:         [SKIP][63] ([fdo#112146]) -> [PASS][64] +3 similar issues
   [63]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb1/igt@gem_exec_async@concurrent-writes-bsd.html
   [64]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb6/igt@gem_exec_async@concurrent-writes-bsd.html

  * igt@gem_exec_schedule@implicit-both-bsd:
    - shard-iclb:         [SKIP][65] ([i915#677]) -> [PASS][66] +1 similar issue
   [65]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb4/igt@gem_exec_schedule@implicit-both-bsd.html
   [66]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb7/igt@gem_exec_schedule@implicit-both-bsd.html

  * igt@gem_exec_schedule@implicit-read-write-bsd1:
    - shard-iclb:         [SKIP][67] ([fdo#109276] / [i915#677]) -> [PASS][68] +1 similar issue
   [67]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb6/igt@gem_exec_schedule@implicit-read-write-bsd1.html
   [68]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb2/igt@gem_exec_schedule@implicit-read-write-bsd1.html

  * igt@gem_exec_schedule@in-order-bsd2:
    - shard-iclb:         [SKIP][69] ([fdo#109276]) -> [PASS][70] +13 similar issues
   [69]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb3/igt@gem_exec_schedule@in-order-bsd2.html
   [70]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb4/igt@gem_exec_schedule@in-order-bsd2.html

  * igt@gem_exec_suspend@basic-s3:
    - shard-kbl:          [DMESG-WARN][71] ([i915#180]) -> [PASS][72] +5 similar issues
   [71]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-kbl6/igt@gem_exec_suspend@basic-s3.html
   [72]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-kbl3/igt@gem_exec_suspend@basic-s3.html

  * igt@gem_exec_whisper@basic-fds-priority:
    - shard-tglb:         [TIMEOUT][73] ([i915#1408]) -> [PASS][74]
   [73]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-tglb3/igt@gem_exec_whisper@basic-fds-priority.html
   [74]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-tglb8/igt@gem_exec_whisper@basic-fds-priority.html

  * igt@gem_ppgtt@flink-and-close-vma-leak:
    - shard-kbl:          [FAIL][75] ([i915#644]) -> [PASS][76]
   [75]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-kbl3/igt@gem_ppgtt@flink-and-close-vma-leak.html
   [76]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-kbl3/igt@gem_ppgtt@flink-and-close-vma-leak.html

  * igt@i915_pm_rps@reset:
    - shard-iclb:         [FAIL][77] ([i915#413]) -> [PASS][78]
   [77]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb1/igt@i915_pm_rps@reset.html
   [78]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb5/igt@i915_pm_rps@reset.html

  * igt@i915_suspend@debugfs-reader:
    - shard-apl:          [DMESG-WARN][79] ([i915#180]) -> [PASS][80] +1 similar issue
   [79]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-apl3/igt@i915_suspend@debugfs-reader.html
   [80]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-apl4/igt@i915_suspend@debugfs-reader.html

  * igt@kms_flip@flip-vs-expired-vblank-interruptible:
    - shard-kbl:          [FAIL][81] ([i915#79]) -> [PASS][82]
   [81]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-kbl6/igt@kms_flip@flip-vs-expired-vblank-interruptible.html
   [82]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-kbl2/igt@kms_flip@flip-vs-expired-vblank-interruptible.html

  * igt@kms_plane_lowres@pipe-a-tiling-x:
    - shard-glk:          [FAIL][83] ([i915#899]) -> [PASS][84]
   [83]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-glk3/igt@kms_plane_lowres@pipe-a-tiling-x.html
   [84]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-glk8/igt@kms_plane_lowres@pipe-a-tiling-x.html

  * igt@kms_psr@psr2_cursor_blt:
    - shard-iclb:         [SKIP][85] ([fdo#109441]) -> [PASS][86]
   [85]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb4/igt@kms_psr@psr2_cursor_blt.html
   [86]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb2/igt@kms_psr@psr2_cursor_blt.html

  * igt@kms_setmode@basic:
    - shard-hsw:          [FAIL][87] ([i915#31]) -> [PASS][88]
   [87]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-hsw2/igt@kms_setmode@basic.html
   [88]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-hsw2/igt@kms_setmode@basic.html
    - shard-kbl:          [FAIL][89] ([i915#31]) -> [PASS][90]
   [89]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-kbl1/igt@kms_setmode@basic.html
   [90]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-kbl7/igt@kms_setmode@basic.html

  
#### Warnings ####

  * igt@gem_linear_blits@normal:
    - shard-apl:          [TIMEOUT][91] ([fdo#111732] / [i915#1322]) -> [TIMEOUT][92] ([i915#1322])
   [91]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-apl7/igt@gem_linear_blits@normal.html
   [92]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-apl3/igt@gem_linear_blits@normal.html

  * igt@gem_userptr_blits@sync-unmap-after-close:
    - shard-hsw:          [DMESG-WARN][93] ([fdo#110789] / [fdo#111870]) -> [DMESG-WARN][94] ([fdo#111870])
   [93]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-hsw2/igt@gem_userptr_blits@sync-unmap-after-close.html
   [94]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-hsw1/igt@gem_userptr_blits@sync-unmap-after-close.html
    - shard-snb:          [DMESG-WARN][95] ([fdo#110789] / [fdo#111870] / [i915#478]) -> [DMESG-WARN][96] ([fdo#111870] / [i915#478])
   [95]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-snb2/igt@gem_userptr_blits@sync-unmap-after-close.html
   [96]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-snb5/igt@gem_userptr_blits@sync-unmap-after-close.html

  * igt@i915_pm_rpm@modeset-non-lpsp-stress-no-wait:
    - shard-tglb:         [SKIP][97] ([fdo#111644] / [i915#1397]) -> [SKIP][98] ([i915#1316])
   [97]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-tglb5/igt@i915_pm_rpm@modeset-non-lpsp-stress-no-wait.html
   [98]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-tglb8/igt@i915_pm_rpm@modeset-non-lpsp-stress-no-wait.html
    - shard-iclb:         [SKIP][99] ([fdo#110892]) -> [SKIP][100] ([i915#1316])
   [99]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-iclb2/igt@i915_pm_rpm@modeset-non-lpsp-stress-no-wait.html
   [100]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-iclb3/igt@i915_pm_rpm@modeset-non-lpsp-stress-no-wait.html

  * igt@runner@aborted:
    - shard-kbl:          ([FAIL][101], [FAIL][102]) ([i915#1389] / [i915#1402] / [i915#92]) -> [FAIL][103] ([i915#92])
   [101]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-kbl2/igt@runner@aborted.html
   [102]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_8130/shard-kbl4/igt@runner@aborted.html
   [103]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/shard-kbl6/igt@runner@aborted.html

  
  {name}: This element is suppressed. This means it is ignored when computing
          the status of the difference (SUCCESS, WARNING, or FAILURE).

  [fdo#103927]: https://bugs.freedesktop.org/show_bug.cgi?id=103927
  [fdo#109271]: https://bugs.freedesktop.org/show_bug.cgi?id=109271
  [fdo#109276]: https://bugs.freedesktop.org/show_bug.cgi?id=109276
  [fdo#109441]: https://bugs.freedesktop.org/show_bug.cgi?id=109441
  [fdo#109642]: https://bugs.freedesktop.org/show_bug.cgi?id=109642
  [fdo#110789]: https://bugs.freedesktop.org/show_bug.cgi?id=110789
  [fdo#110841]: https://bugs.freedesktop.org/show_bug.cgi?id=110841
  [fdo#110854]: https://bugs.freedesktop.org/show_bug.cgi?id=110854
  [fdo#110892]: https://bugs.freedesktop.org/show_bug.cgi?id=110892
  [fdo#111068]: https://bugs.freedesktop.org/show_bug.cgi?id=111068
  [fdo#111644]: https://bugs.freedesktop.org/show_bug.cgi?id=111644
  [fdo#111732]: https://bugs.freedesktop.org/show_bug.cgi?id=111732
  [fdo#111870]: https://bugs.freedesktop.org/show_bug.cgi?id=111870
  [fdo#112080]: https://bugs.freedesktop.org/show_bug.cgi?id=112080
  [fdo#112146]: https://bugs.freedesktop.org/show_bug.cgi?id=112146
  [i915#129]: https://gitlab.freedesktop.org/drm/intel/issues/129
  [i915#1316]: https://gitlab.freedesktop.org/drm/intel/issues/1316
  [i915#1322]: https://gitlab.freedesktop.org/drm/intel/issues/1322
  [i915#1389]: https://gitlab.freedesktop.org/drm/intel/issues/1389
  [i915#1397]: https://gitlab.freedesktop.org/drm/intel/issues/1397
  [i915#1402]: https://gitlab.freedesktop.org/drm/intel/issues/1402
  [i915#1408]: https://gitlab.freedesktop.org/drm/intel/issues/1408
  [i915#155]: https://gitlab.freedesktop.org/drm/intel/issues/155
  [i915#180]: https://gitlab.freedesktop.org/drm/intel/issues/180
  [i915#250]: https://gitlab.freedesktop.org/drm/intel/issues/250
  [i915#31]: https://gitlab.freedesktop.org/drm/intel/issues/31
  [i915#34]: https://gitlab.freedesktop.org/drm/intel/issues/34
  [i915#413]: https://gitlab.freedesktop.org/drm/intel/issues/413
  [i915#478]: https://gitlab.freedesktop.org/drm/intel/issues/478
  [i915#54]: https://gitlab.freedesktop.org/drm/intel/issues/54
  [i915#58]: https://gitlab.freedesktop.org/drm/intel/issues/58
  [i915#644]: https://gitlab.freedesktop.org/drm/intel/issues/644
  [i915#677]: https://gitlab.freedesktop.org/drm/intel/issues/677
  [i915#79]: https://gitlab.freedesktop.org/drm/intel/issues/79
  [i915#899]: https://gitlab.freedesktop.org/drm/intel/issues/899
  [i915#92]: https://gitlab.freedesktop.org/drm/intel/issues/92
  [k.org#198133]: https://bugzilla.kernel.org/show_bug.cgi?id=198133


Participating hosts (10 -> 8)
------------------------------

  Missing    (2): pig-skl-6260u pig-glk-j5005 


Build changes
-------------

  * CI: CI-20190529 -> None
  * IGT: IGT_5506 -> IGTPW_4299
  * Piglit: piglit_4509 -> None

  CI-20190529: 20190529
  CI_DRM_8130: cf47ad003bc75f001bd33caedb28c8ba2e3c3d33 @ git://anongit.freedesktop.org/gfx-ci/linux
  IGTPW_4299: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/index.html
  IGT_5506: 59fd8a0d01dac58dc6c7d86ef391ed4393ab5aae @ git://anongit.freedesktop.org/xorg/app/intel-gpu-tools
  piglit_4509: fdc5a4ca11124ab8413c7988896eec4c97336694 @ git://anongit.freedesktop.org/piglit

== Logs ==

For more details see: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_4299/index.html
_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 8+ messages in thread

* Re: [igt-dev] [PATCH i-g-t 0/2] Test configurable poll delay in perf OA
  2020-03-12 23:05 [igt-dev] [PATCH i-g-t 0/2] Test configurable poll delay in perf OA Umesh Nerlige Ramappa
                   ` (4 preceding siblings ...)
  2020-03-13 12:38 ` [igt-dev] ✓ Fi.CI.IGT: " Patchwork
@ 2020-03-13 13:27 ` Lionel Landwerlin
  5 siblings, 0 replies; 8+ messages in thread
From: Lionel Landwerlin @ 2020-03-13 13:27 UTC (permalink / raw)
  To: Umesh Nerlige Ramappa, igt-dev, Ashutosh Dixit

On 13/03/2020 01:05, Umesh Nerlige Ramappa wrote:
> Add tests that verify the configurable poll delay in perf OA.
>
> Lionel Landwerlin (2):
>    include/drm-uapi: Update i915_drm.h for perf OA APIs
>    tests/perf: new tests for parameterized OA buffer polling
>
>   include/drm-uapi/i915_drm.h |  13 ++++
>   tests/perf.c                | 132 ++++++++++++++++++++++++++----------
>   2 files changed, 111 insertions(+), 34 deletions(-)
>
Just found a few nits, but otherwise it looks good.

That said I wrote those tests so... ;)


-Lionel

_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 8+ messages in thread

end of thread, other threads:[~2020-03-13 13:27 UTC | newest]

Thread overview: 8+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2020-03-12 23:05 [igt-dev] [PATCH i-g-t 0/2] Test configurable poll delay in perf OA Umesh Nerlige Ramappa
2020-03-12 23:05 ` [igt-dev] [PATCH i-g-t 1/2] include/drm-uapi: Update i915_drm.h for perf OA APIs Umesh Nerlige Ramappa
2020-03-12 23:05 ` [igt-dev] [PATCH i-g-t 2/2] tests/perf: new tests for parameterized OA buffer polling Umesh Nerlige Ramappa
2020-03-13 11:43   ` Lionel Landwerlin
2020-03-12 23:30 ` [igt-dev] ✗ GitLab.Pipeline: failure for Test configurable poll delay in perf OA Patchwork
2020-03-12 23:40 ` [igt-dev] ✓ Fi.CI.BAT: success " Patchwork
2020-03-13 12:38 ` [igt-dev] ✓ Fi.CI.IGT: " Patchwork
2020-03-13 13:27 ` [igt-dev] [PATCH i-g-t 0/2] " Lionel Landwerlin

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.